@@ -6,6 +6,11 @@ import sys
 import time
 import pickle
 
+# don't run this as root, please...
+if os.geteuid() == 0:
+  print "Don't run this as root, please..."
+  sys.exit(0)
+
 DL_DIR = "/home/user/MyDocs/.videos/ytcli" 
 DL_LOG = "/tmp/ytcli_log"
 Q_RUNLOCK = "/tmp/ytcli_runlock"
@@ -50,7 +55,8 @@ def download(vid):
   signal.signal(signal.SIGUSR2, cancel_handler)
   dl.wait()
   call = ("run-standalone.sh dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:\'" + vid[0] + " completed\'")
-  os.system(call)
+  call = shlex.split(call)
+  subprocess.Popen(call)
 
 def acquire_lock():
   while True:
